@@ -6,6 +6,7 @@ import (
 	"github.com/wtfutil/wtf/modules/airbrake"
 	"github.com/wtfutil/wtf/modules/asana"
 	"github.com/wtfutil/wtf/modules/azuredevops"
+	"github.com/wtfutil/wtf/modules/azurelogs"
 	"github.com/wtfutil/wtf/modules/bamboohr"
 	"github.com/wtfutil/wtf/modules/bargraph"
 	"github.com/wtfutil/wtf/modules/buildkite"
@@ -55,6 +56,7 @@ import (
 	"github.com/wtfutil/wtf/modules/opsgenie"
 	"github.com/wtfutil/wtf/modules/pagerduty"
 	"github.com/wtfutil/wtf/modules/pihole"
+	"github.com/wtfutil/wtf/modules/ping"
 	"github.com/wtfutil/wtf/modules/pivotal"
 	"github.com/wtfutil/wtf/modules/pocket"
 	"github.com/wtfutil/wtf/modules/power"
@@ -127,6 +129,9 @@ func MakeWidget(
 	case "azuredevops":
 		settings := azuredevops.NewSettingsFromYAML(moduleName, moduleConfig, config)
 		widget = azuredevops.NewWidget(tviewApp, redrawChan, pages, settings)
+	case "azurelogs":
+		settings := azurelogs.NewSettingsFromYAML(moduleName, moduleConfig, config)
+		widget = azurelogs.NewWidget(tviewApp, redrawChan, pages, settings)
 	case "bamboohr":
 		settings := bamboohr.NewSettingsFromYAML(moduleName, moduleConfig, config)
 		widget = bamboohr.NewWidget(tviewApp, redrawChan, settings)
@@ -274,6 +279,9 @@ func MakeWidget(
 	case "pihole":
 		settings := pihole.NewSettingsFromYAML(moduleName, moduleConfig, config)
 		widget = pihole.NewWidget(tviewApp, redrawChan, pages, settings)
+	case "ping":
+		settings := ping.NewSettingsFromYAML(moduleName, moduleConfig, config)
+		widget = ping.NewWidget(tviewApp, redrawChan, settings)
 	case "power":
 		settings := power.NewSettingsFromYAML(moduleName, moduleConfig, config)
 		widget = power.NewWidget(tviewApp, redrawChan, settings)
