@@ -15,9 +15,9 @@ type Widget struct {
 	err    error
 }
 
-func NewWidget(tviewApp *tview.Application, pages *tview.Pages, settings *Settings) *Widget {
+func NewWidget(tviewApp *tview.Application, redrawChan chan bool, pages *tview.Pages, settings *Settings) *Widget {
 	widget := Widget{
-		TextWidget: view.NewTextWidget(tviewApp, pages, settings.Common),
+		TextWidget: view.NewTextWidget(tviewApp, redrawChan, pages, settings.Common),
 		settings:   settings,
 	}
 
@@ -57,7 +57,7 @@ func (widget *Widget) content() (string, string, bool) {
 		return title, widget.err.Error(), true
 	}
 
-	displayData := NewPipelinesDisplayData(widget.builds)
+	displayData := newPipelinesDisplayData(widget.builds)
 
 	return title, displayData.Content(), false
 }
