@@ -18,8 +18,12 @@ type Settings struct {
 	font           string `help:"The font of the clock." values:"bigfont or digitalfont"`
 	hourFormat     string `help:"The format of the clock." values:"12 or 24"`
 	dateFormat     string `help:"The format of the date."`
+	dateTitle      bool   `help:"Whether or not to display date as widget title"`
 	withDate       bool   `help:"Whether or not to display date information"`
+	withUTC        bool   `help:"Whether or not to display UTC information"`
+	withEpoch      bool   `help:"Whether or not to display Epoch information"`
 	withDatePrefix bool   `help:"Whether or not to display Date: prefix"`
+	centerAlign    bool   `help:"Whether or not to use center align in widget"`
 }
 
 // NewSettingsFromYAML creates a new settings instance from a YAML config block
@@ -31,8 +35,12 @@ func NewSettingsFromYAML(name string, ymlConfig *config.Config, globalConfig *co
 		font:           ymlConfig.UString("font"),
 		hourFormat:     ymlConfig.UString("hourFormat", "24"),
 		dateFormat:     ymlConfig.UString("dateFormat", "Monday January 02 2006"),
+		dateTitle:      ymlConfig.UBool("dateTitle", false),
 		withDate:       ymlConfig.UBool("withDate", true),
+		withUTC:        ymlConfig.UBool("withUTC", true),
+		withEpoch:      ymlConfig.UBool("withEpoch", true),
 		withDatePrefix: ymlConfig.UBool("withDatePrefix", true),
+		centerAlign:    ymlConfig.UBool("centerAlign", false),
 	}
 
 	return &settings
