@@ -53,7 +53,7 @@ func rollbarItemRequest(accessToken, assignedToName string, activeOnly bool) (*h
 	defer func() { _ = resp.Body.Close() }()
 
 	if resp.StatusCode < 200 || resp.StatusCode > 299 {
-		return nil, fmt.Errorf(resp.Status)
+		return nil, fmt.Errorf("%s", resp.Status)
 	}
 
 	return resp, nil
