@@ -3,7 +3,7 @@ package spotify
 import (
 	"time"
 
-	"github.com/gdamore/tcell"
+	"github.com/gdamore/tcell/v2"
 )
 
 func (widget *Widget) initializeKeyboardControls() {
